<?php

$GLOBALS['LSlang'] = array (

# LSobjects.LSpeople.attrs.lsGodfatherDn.label
# LSobjects.LSgroup.attrs.lsGodfatherDn.label
# LSobjects.LScompany.attrs.lsGodfatherDn.label
"Accountable(s)" =>
  "Responsable(s)",

# ldap_servers.0.LSprofiles.admin.label
"Administrator" =>
  "Administrateur",

# LSobjects.LSpeople.attrs.loginShell.help_info
"Allow user to connect a POSIX system." =>
  "Autorisie l'utilisateur à se connecter aux systèmes POSIX.",

# LSobjects.LSpeople.LSrelation.groups.label
"Belongs to groups ..." =>
  "Appartient aux groupes ...",

# LSobjects.LSpeople.LSform.layout.Civilite.label
# LSobjects.LSpeople.attrs.personalTitle.label
"Civility" =>
  "Civilité",

# LSobjects.LSpeople.attrs.loginShell.label
"Command shell" =>
  "Interpréteur de commande",

# LSobjects.LScompany.label
"Companies" =>
  "Sociétés",

# ldap_servers.1.subDnLabel
"Company" =>
  "Société",

# LSobjects.LSpeople.attrs.description.label
# LSobjects.LSgroup.attrs.description.label
# LSobjects.LScompany.attrs.description.label
"Description" =>
  "Description",

# LSobjects.LSpeople.LSrelation.groups.emptyText
"Doesn't belong to any group." =>
  "N'appartient à aucun groupe.",

# LSobjects.LSpeople.LSrelation.godfather.emptyText
"Doesn't sponsor any user." =>
  "Ne parraine aucun utilisateur.",

# LSobjects.LSpeople.attrs.mail.label
"E-mail address" =>
  "Adresse e-mail",

# LSobjects.LSpeople.LSsearch.customActions.exportSearchResultAsCSV.label
"Export result as CSV" =>
  "Exporter le résultat au format CSV",

# LSobjects.LSpeople.attrs.jpegPhoto.check_data.filesize.msg
"File size is not valid." =>
  "La taille du fichier est invalide.",

# LSobjects.LSpeople.attrs.jpegPhoto.check_data.imagefile.msg
"File type is not valid." =>
  "Le type de fichier est invalide.",

# LSobjects.LSpeople.attrs.givenName.label
"First Name" =>
  "Prénom",

# templates/default/import.tpl:11
"Format" =>
  "Format",

# LSobjects.LSpeople.attrs.cn.label
"Full Name" =>
  "Nom complet",

# LSobjects.LSpeople.attrs.mail.check_data.email.msg
"Given email address is invalid." =>
  "L'adresse mail saisie est invalide.",

# ldap_servers.0.LSprofiles.godfather.label
"Godfather" =>
  "Parrain",

# LSobjects.LSpeople.LSrelation.godfather.label
"Godfather of ..." =>
  "Parrain de ...",

# LSobjects.LSgroup.label
"Groups" =>
  "Groupes",

# LSobjects.LSpeople.attrs.homeDirectory.label
"Home Directory" =>
  "Dossier personnel",

# LSobjects.LSpeople.attrs.uid.check_data.regex.msg
"Identifier must contain alphanumeric values, dots (.) and dashes (-) only." =>
  "L'identifiant doit contenir uniquement des valeurs alpha-numériques, avec eventuellement des points (.) et des tirets (-).",

# LSobjects.LSpeople.attrs.gidNumber.html_options.possible_values.1.label
"LDAP Groups" =>
  "Groupes LDAP",

# ldap_servers.0.name
"LSexample" =>
  "LSexemple",

# ldap_servers.1.name
"LSexample - multi-company" =>
  "LSexemple - multi-société",

# ldap_servers.0.recoverPassword.recoveryHashMail.subject
# ldap_servers.1.recoverPassword.recoveryHashMail.subject
"LSexample : Recovering your password." =>
  "LSexemple : Récupération de votre mot de passe.",

# ldap_servers.0.recoverPassword.newPasswordMail.subject
# ldap_servers.1.recoverPassword.newPasswordMail.subject
# LSobjects.LSpeople.attrs.userPassword.html_options.mail.subject
"LSexample : Your new credentials." =>
  "LSexemple : Votre nouveau mot de passe.",

# LSobjects.LSpeople.attrs.sn.label
"Last Name" =>
  "Nom",

# LSobjects.LSpeople.LSsearch.extraDisplayedColumns.mail.label
"Mail" =>
  "Mail",

# LSobjects.LSpeople.attrs.gidNumber.label
"Main group" =>
  "Groupe principal",

# LSobjects.LSgroup.attrs.uniqueMember.label
"Members" =>
  "Membres",

# LSobjects.LSpeople.attrs.personalTitle.html_options.possible_values.M.
"Mr" =>
  "M.",

# LSobjects.LSpeople.attrs.personalTitle.html_options.possible_values.Mme
"Mrs" =>
  "Mme",

# LSobjects.LSpeople.attrs.personalTitle.html_options.possible_values.Mlle
"Ms" =>
  "Mlle",

# LSobjects.LSgroup.attrs.cn.label
# LSobjects.LScompany.attrs.ou.label
"Name" =>
  "Nom",

# LSobjects.LSgroup.attrs.cn.check_data.alphanumeric.msg
"Name must contain alphanumeric values only." =>
  "Le nom doit contenir uniquement des valeurs alpha-numériques.",

# templates/default/viewSearch.tpl:120
"Nb / page :" =>
  "Nb / page :",

# LSobjects.LSpeople.attrs.uidNumber.label
"Numeric identifier" =>
  "Identifiant numérique",

# LSobjects.LSgroup.attrs.lsGodfatherDn.validation.0.msg
# LSobjects.LScompany.attrs.lsGodfatherDn.validation.0.msg
"One or several of these users don't exist." =>
  "Un ou plusieurs utilisateurs n'existent pas.",

# LSobjects.LSpeople.attrs.lsGodfatherDn.validation.0.msg
"One or several users don't exist." =>
  "Un ou plusieurs utilisateurs n'existent pas.",

# LSobjects.LSpeople.attrs.lsRecoveryHash.label
"Password recovery hash" =>
  "Hash de récupération de mot de passe",

# LSobjects.LSpeople.attrs.jpegPhoto.label
"Picture" =>
  "Image",

# LSobjects.LSpeople.attrs.jpegPhoto.check_data.imagesize.msg
"Picture size is not valid." =>
  "La taille de l'image est invalide.",

# LSobjects.LSpeople.LSform.layout.Posix.label
"Posix" =>
  "Posix",

# LSobjects.LSpeople.LSform.layout.Samba.label
"Samba" =>
  "Samba",

# LSobjects.LSpeople.attrs.sambaSID.label
"Samba Identifier" =>
  "Identifiant Samba",

# LSobjects.LSpeople.attrs.sambaLMPassword.label
"Samba Password (LM)" =>
  "Mot de passe Samba (LM)",

# LSobjects.LSpeople.attrs.sambaNTPassword.label
"Samba Password (NT)" =>
  "Mot de passe Samba (NT)",

# LSobjects.LSpeople.LSform.dataEntryForm.simple.label
"Simple" =>
  "Simple",

# LSobjects.LSpeople.attrs.givenName.check_data.alphanumeric.msg
"The first name must contain alphanumeric values only." =>
  "Le prénom doit contenir uniquement des caractères alpha-numérique.",

# LSobjects.LSpeople.attrs.uidNumber.check_data.numeric.msg
"The numeric identifier must be an integer." =>
  "L'identifiant numérique doit forcement être un entier.",

# LSobjects.LSpeople.attrs.gidNumber.validation.0.msg
"This group doesn't exist." =>
  "Ce groupe n'existe pas.",

# LSobjects.LSpeople.attrs.uid.validation.0.msg
"This identifier is already used." =>
  "Cet identifiant est déjà utilisé.",

# LSobjects.LSpeople.attrs.uidNumber.validation.0.msg
"This uid is already used." =>
  "Cet uid est déjà utilisé.",

# ldap_servers.0.recoverPassword.recoveryHashMail.msg
# ldap_servers.1.recoverPassword.recoveryHashMail.msg
"To proceed password recovery procedure, please follow that link:
%{url}" =>
  "Pour poursuivre la procédure de récupération de mot de passe, merci de suivre ce lien :
%{url}",

# LSobjects.LSpeople.label
"Users" =>
  "Utilisateurs",

# LSobjects.LSpeople.LSsearch.predefinedFilters.(jpegPhoto=*)
"With photo" =>
  "Avec photo",

# LSobjects.LSpeople.LSsearch.predefinedFilters.(!(jpegPhoto=*))
"Without photo" =>
  "Sans photo",

# ldap_servers.0.recoverPassword.newPasswordMail.msg
# ldap_servers.1.recoverPassword.newPasswordMail.msg
"Your new password : %{mdp}" =>
  "Votre nouveau mot de passe : %{mdp}",

# LSobjects.LSpeople.attrs.userPassword.html_options.mail.msg
"Your password has been changed.
Login : %{uid}
New password : %{password}" =>
  "Votre mot de passe a été changé.
Identifiant : %{uid}
Nouveau mot de passe : %{password}",

# LSobjects.LSpeople.attrs.userPassword.check_data.password.msg
"Your password must contain from 8 to 10 characters." =>
  "Votre mot de passe doit contenir entre 8 et 10 caractères.",

);
